#ifndef GAMEOBJECT_H
#define GAMEOBJECT_H
/*========================================================================
Class Name	: GameObject
Authors		: Ewan Duncan, Andrew Hoque
Description	: Class that represents an object in the game that gets updated
			  and rendered.  
=========================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include <SFML/Graphics.hpp>
#include <SFML/Graphics/Text.hpp>
#include <map>
#include <tmx/MapLoader.h>
#include <tmx/MapLayer.h>
#include <LTBL/Light/LightSystem.h>
#include <LTBL/Light/Light_Point.h>
#include <LTBL/Utils.h>

#include "services.h"
#include "animation.h"

enum TYPE { kPlayer, kOrb, kBoulder, kProp, kTree, kSoundTrigger, kLight, kFire, kWeb, kMovingProp };

enum Direction
{
	north,
	south,
	west,
	east,
	north_west,
	north_east,
	south_west,
	south_east
};

// Define screen dimentions.
const float kWindowWidth = 1280.f,
kWindowHeight = 720.f;

class Section;

/*-------------------------------------------------------------------------
GAMEOBJECT CLASS
-------------------------------------------------------------------------*/
class GameObject : public sf::RectangleShape
{
public:

	GameObject();
	virtual ~GameObject();

	void set_velocity(const sf::Vector2f& velocity) { velocity_ = velocity; }
	const sf::Vector2f& get_velocity() const { return velocity_; }

	void set_x_velocity(const float xvelocity) { velocity_.x = xvelocity; }
	void set_y_velocity(const float yvelocity) { velocity_.y = yvelocity; }

	void set_active(const bool active) { active_ = active; }
	const bool get_active() const { return active_; }

	void set_collidable(const bool collidable) { collidable_ = collidable; }
	const bool get_collidable() const { return collidable_; }

	void set_drawable(const bool drawable) { drawable_ = drawable; }
	const bool get_drawable() const { return drawable_; }

	void set_type(const TYPE type) { type_ = type; }
	const TYPE get_type() const { return type_; }

	void set_has_light(const bool has_light) { has_light_ = has_light; }
	const bool get_has_light() const { return has_light_; }

	void set_light_on(const bool light_on) { light_on_ = light_on; }
	const bool get_light_on() const { return light_on_; }

	const bool get_dead_only() const { return dead_only_; }
	void set_dead_only(const bool dead_only) { dead_only_ = dead_only; }

	const int get_layer(){ return layer_; }

	void MoveTo(float xposition, float yposition),
		SetX(float xposition),
		SetY(float yposition),
		MoveDeltaX(float xdistance),
		MoveDeltaY(float ydistance);
	bool CollisionDetection(GameObject& Object);

	static void Init(sf::RenderTexture* render_texture, sf::Sprite* world_sprite, tmx::MapLoader* map_loader);
	virtual void Update(){};
	void CreateLight(float radius, float bleed, Color3f colour);
	void CreateLight();
	void Render();
	void MapCollision(sf::Vector2f temp_position);
	void TurnLightOn();
	void TurnLightOff();

protected:

	sf::Vector2f velocity_;

	int layer_;

	bool active_,
		collidable_,
		drawable_,
		has_light_,
		light_on_,
		dead_only_;

	ltbl::Light_Point* light_;

	std::map<std::string, Animation*> animation_map_;

	TYPE type_;
	Direction direction_;

	static sf::RenderTexture* render_texture_;
	static sf::Sprite* world_sprite_;
	static tmx::MapLoader* map_loader_;
};

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
#endif
