#ifndef GAME_STATE_H
#define GAME_STATE_H

/*=========================================================================
Class Name	: GameState
Authors		: Ewan Duncan, Andrew Hoque
Description	: Contains in game logic.  Sets up tools used in 
			  the game.  Manages the different sections(areas)
			  of the game world.
========================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include <SFML/Graphics.hpp>
#include <SFML/Audio.hpp>

#include "state_manager.h"
#include "sound_object.h"
#include "game_object.h"
#include "player.h"
#include "music_player.h"
#include <tmx/MapLoader.h>
#include <tmx/MapLayer.h>
#include "sound_player.h"
#include "orb.h"

#include <vector>
#include <map>

#include "section.h"

/*-------------------------------------------------------------------------
GAMESTATE CLASS
-------------------------------------------------------------------------*/
class GameState : public State
{
 public:
	 void Init(),
		 CleanUp(),
		 Pause(),
		 Resume(),
		 Update(StateManager *state_manager),
		 ViewUpdate(),
		 Render();

private:

	void LoadSections();

	std::string current_section_;
	std::map<std::string, Section*> section_map_;

	Section* test_section_;
	Section* test_section2_;
	
	Player* player_;
	
	tmx::MapLoader* map_loader_;
	sf::View view_;

	ltbl::LightSystem* light_system_;
	ltbl::Light_Point* testLight;

	sf::RenderTexture render_texture_;
	sf::Sprite world_sprite_;
};

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
#endif
