#ifndef INPUT_MANAGER_H
#define INPUT_MANAGER_H

/*========================================================================
Class Name	: InputManager
Authors		: Ewan Duncan
Description	: Class that encapsulates SFML's keyboard and add further 
			  functionality.  Also adds Xbox 360 controller support.
=========================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include <SFML/System/Vector2.hpp>
#include <SFML/Window/Keyboard.hpp>
#include <windows.h>
#include <XInput.h>

/*-------------------------------------------------------------------------
INPUTMANAGER CLASS
-------------------------------------------------------------------------*/
class InputManager
{
 public:
    typedef unsigned int    t_controller_number;
    typedef unsigned short  t_button_number;

    enum
	{
		DPAD_UP     = 0x0001,
        DPAD_DOWN   = 0x0002,
        DPAD_LEFT   = 0x0004,
        DPAD_RIGHT  = 0x0008,
        START       = 0x0010,
        BACK        = 0x0020,
        LEFT_THUMB  = 0x0040,
        RIGHT_THUMB = 0x0080,
        LB          = 0x0100,
        RB          = 0x0200,
        A           = 0x1000,
        B           = 0x2000,
        X           = 0x4000,
        Y           = 0x8000,
   };

	bool IsControllerConnected(t_controller_number controller_number);
	unsigned int GetButtonCount(t_controller_number controller_number) { return 14; }
	bool IsButtonPressed(t_controller_number controller_number, t_button_number button_number),
		IsButtonDown(t_controller_number controller_number, t_button_number button_number),
		IsButtonReleased(t_controller_number controller_number, t_button_number button_number),
		IsKeyPressed(sf::Keyboard::Key key),
		IsKeyDown(sf::Keyboard::Key key),
		IsKeyReleased(sf::Keyboard::Key key);

    bool IsAnyXBox360ControllerConnected();
	void SetCurrentState(),
		 SetPreviousState();

	void SetTriggers(t_controller_number controller_number);
	void SetSticksPosition(t_controller_number controller_number);

	void Update(t_controller_number controller_number);

	inline const sf::Vector2f& get_left_stick_position() const {return left_stick_; }
	inline const sf::Vector2f& get_right_stick_position() const {return right_stick_; }
	inline const float get_left_trigger() const {return left_trigger_; }
	inline const float get_right_trigger() const {return right_trigger_; }

	void SetVibration(t_controller_number controller_number, float left_motor = 0.0f, float right_motor = 0.0f);

 private:
	XINPUT_STATE current_controller_state_,
				 previous_controller_state_;

	sf::Vector2f left_stick_,
				 right_stick_;
	float left_trigger_,
		  right_trigger_;
	bool current_key_states_[sf::Keyboard::KeyCount],
		 previous_key_states_[sf::Keyboard::KeyCount];
};

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
#endif
