#ifndef PLAYER_H
#define PLAYER_H

/*============================================================
Class Name	: Player
Authors		: Ewan Duncan, Lewis Bayne, Andrew Hoque
Description	: Object that represents the player in the game.  
			  Takes input from user and acts on it.  
============================================================*/

/*------------------------------------------------------------
INCLUDES
------------------------------------------------------------*/
#include <iostream>
using std::cout;
using std::endl;

#include <fstream>
#include <sstream>
using std::ifstream;

#include "game_object.h"
#include "animation.h"

/*------------------------------------------------------------
PLAYER CLASS
------------------------------------------------------------*/
class Player : public GameObject
{
	public:
		Player( float x , float y );
		~Player();

		void Update(),
			WalkThroughDoor(std::string direction_),
			distanceChange(GameObject& Object);
		
		void set_speed(const float speed) { speed_ = speed; }
		const float get_speed() const { return speed_; }

		void set_moving(const bool moving) { moving_ = moving; }
		const bool get_moving() const { return moving_; }

		void set_controllable(const bool controllable) { controllable_ = controllable; }
		const bool get_controllable() const { return controllable_; }

		void set_push_power(const bool push_power){ push_boulder_power_ = push_power; }
		void set_float_power(const bool float_power){ float_power_ = float_power; }

		void set_fire_power(const bool fire_power){ fire_power_ = fire_power;
													just_obtained_fire_ = fire_power; 
												  }

		void set_pit_power(const bool pit_power){ pit_float_power_ = pit_power; }

	private:

		void LoadProperties();

		void Input();

		void MoveNorthWest();
		void MoveNorthEast();
		void MoveSouthWest();
		void MoveSouthEast();

		void MoveUp();
		void MoveDown();
		void MoveLeft();
		void MoveRight();

		void Idle();
	
		void FloatingCollisions(sf::Vector2f temp_position);
		void SetUVCoordinates(float x, float y);

		float speed_;
		float default_speed_;

		float fire_ball_limiter_;

		bool moving_;
		bool controllable_;
		bool floating_;
		bool push_boulder_power_;
		bool float_power_;
		bool fire_power_;
		bool just_obtained_fire_;
		bool pit_float_power_;
};

/*------------------------------------------------------------
END OF FILE
------------------------------------------------------------*/
#endif
