#ifndef SECTION_H
#define SECTION_H

/*========================================================================
Class Name	: Section
Authors		: Ewan Duncan, Andrew Hoque
Description	: Contains the logic for an area of the map.  
			  Switches between dead and alive versions and 
			  switches to other sections.  Updates and renders
			  all game objects.  Uses shaders to make map and 
			  sections transitions smoother.  
=======================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include "map.h"

/*-------------------------------------------------------------------------
SECTION CLASS
-------------------------------------------------------------------------*/
class Section
{

public:

	Section(std::string dead_map_name, std::string living_map_name, tmx::MapLoader* map_loader, Player* player, sf::RenderTexture* render_texture, sf::Sprite* world_sprite,
		sf::RenderWindow* window);

	void Init();

	void Render(),
		 DeadToAliveLightsOff(),
		 SectionToSectionLightsOff();

	bool Update(std::string &current_section);

private:

	void LoadShaders(),
		 SetUpObjects(),
		 OrbPickup(),
		 Pixelate(),
		 Vignette(),
		 MovePlayerToDoor(),
		 RemoveDeadOnlyObjects();

	bool ChangeSection(std::string &current_section);

	std::vector<GameObject*> section_objects_;
	Player* player_;

	sf::RenderTexture* render_texture_;
	sf::Sprite* world_sprite_;
	sf::RenderWindow* window_;

	tmx::MapLoader* map_loader_;

	sf::Shader pixelate_shader_,
			   vignette_shader_;

	std::string	living_map_name_,
				dead_map_name_,
				new_section_;

	Map living_map_,
		dead_map_;

	float pixel_factor_;

	bool alive_,
		screen_transition_,
		fully_pixelated_,
		map_switched_,
		visited_;

	static std::string destination_door_,
					   door_direction_;

	static bool went_through_door_,
				fully_vignetted_,
				vignetting_map_;

	static float vignette_factor_;
};

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
#endif
