/*========================================================================
Class Name	: Services
Authors		: Andrew Hoque, Ewan Duncan
Description	: Class that gives access to management classes, the light
system and a collection of game objects that are currently
being used by the program.
=========================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include "services.h"


/*-------------------------------------------------------------------------
CONSTRUCTORS
-------------------------------------------------------------------------*/
Services::Services()
{
	
}

/*-------------------------------------------------------------------------
MEMBER FUNCTIONS
-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------
Name	: Instance
Purpose	: Returns a static instance of services.  
-------------------------------------------------------------------------*/
Services& Services::Instance()
{
	static Services* instance_ = new Services(); 
	return *instance_;
}

/*-------------------------------------------------------------------------
Name	: GetInputManager
Purpose	: Returns the input manager.  
-------------------------------------------------------------------------*/
InputManager& Services::GetInputManager()
{
	return input_manager_;
}

/*-------------------------------------------------------------------------
Name	: GetMusicPlayer
Purpose	: Returns the music player.
-------------------------------------------------------------------------*/
MusicPlayer& Services::GetMusicPlayer() 
{
	return music_player_;
}

/*-------------------------------------------------------------------------
Name	: GetSoundPlayer
Purpose	: Returns the sound player.
-------------------------------------------------------------------------*/
SoundPlayer& Services::GetSoundPlayer()
{
	return sound_player_;
}

/*-------------------------------------------------------------------------
Name	: GetTextureManager
Purpose	: Returns the texture manager.
-------------------------------------------------------------------------*/
TextureManager& Services::GetTextureManager()
{
	return texture_manager_;
}

/*-------------------------------------------------------------------------
Name	: GetAnimatedPropManager
Purpose	: Returns the animated prop manager.
-------------------------------------------------------------------------*/
AnimatedPropManager& Services::GetAnimatedPropManager()
{
	return animated_prop_manager_;
}

/*-------------------------------------------------------------------------
Name	: GetMovingPropManager
Purpose	: Returns the animated prop manager.
-------------------------------------------------------------------------*/
MovingPropManager& Services::GetMovingPropManager()
{
	return moving_prop_manager_;
}

/*-------------------------------------------------------------------------
Name	: SetLightSystem
Purpose	: Sets the light system.  
-------------------------------------------------------------------------*/
void Services::SetLightSystem(ltbl::LightSystem* light_system)
{
	light_system_ = light_system;
}

/*-------------------------------------------------------------------------
Name	: GetLightSystem
Purpose	: Returns the light system.
-------------------------------------------------------------------------*/
ltbl::LightSystem* Services::GetLightSystem()
{
	return light_system_;
}

/*-------------------------------------------------------------------------
Name	: SetObjectsInUse
Purpose	: Sets the game objects in use.  
-------------------------------------------------------------------------*/
void Services::SetObjectsInUse(std::vector<GameObject*>* objects_in_use)
{
	objects_in_use_ = objects_in_use;
}

/*-------------------------------------------------------------------------
Name	: GetObjectsInUse
Purpose	: Returns the games objects in use.
-------------------------------------------------------------------------*/
std::vector<GameObject*>* Services::GetObjectsInUse()
{
	return objects_in_use_;
}

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
