#ifndef SERVICES_H
#define SERVICES_H

/*========================================================================
Class Name	: Services
Authors		: Andrew Hoque, Ewan Duncan
Description	: Class that gives access to management classes, the light 
			  system and a collection of game objects that are currently 
			  being used by the program.  
=========================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include <LTBL/Light/LightSystem.h>
#include <LTBL/Light/Light_Point.h>
#include <LTBL/Utils.h>

#include "input_manager.h"
#include "music_player.h"
#include "sound_player.h"
#include "texture_manager.h"
#include "animated_prop_manager.h"
#include "moving_prop_manager.h"

class GameObject;

/*-------------------------------------------------------------------------
SERVICES CLASS
-------------------------------------------------------------------------*/
class Services
{
 public:

	static Services& Instance();

	InputManager& GetInputManager();
	MusicPlayer& GetMusicPlayer();
	SoundPlayer& GetSoundPlayer();
	TextureManager& GetTextureManager();
	AnimatedPropManager& GetAnimatedPropManager();
	MovingPropManager& GetMovingPropManager();
	ltbl::LightSystem* GetLightSystem();
	void SetLightSystem(ltbl::LightSystem* light_system);
	void SetObjectsInUse(std::vector<GameObject*>* objects_in_use);
	std::vector<GameObject*>* GetObjectsInUse();

 private:

	Services();

	InputManager input_manager_;
	MusicPlayer music_player_;
	SoundPlayer sound_player_;
	TextureManager texture_manager_;
	AnimatedPropManager animated_prop_manager_;
	MovingPropManager moving_prop_manager_;
	ltbl::LightSystem* light_system_;
	std::vector<GameObject*>* objects_in_use_;
};

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
#endif
