/*=========================================================================
Class Name	: StartState
Authors		: Ewan Duncan
Description	: Displays the start screen
========================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include "start_state.h"

#include "game_state.h"
#include "services.h"

/*-------------------------------------------------------------------------
MEMBER FUNCTIONS
-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------
Name	: Init
Purpose	: Initialises texture used for the start screen.  
-------------------------------------------------------------------------*/
void StartState::Init()
{
	if(!texture_.loadFromFile("media/Sprites/start_screen.png"))
	{
		cout << "textures not found";
	}

	const sf::Texture *pTexture = &texture_;

	start_.setTexture(pTexture);
	start_.setSize(sf::Vector2f(kWindowWidth, kWindowHeight));
	start_.setPosition(0, 0);
}

/*-------------------------------------------------------------------------
Name	: CleanUp
Purpose	: Deletes objects no longer in use.
-------------------------------------------------------------------------*/
void StartState::CleanUp()
{

}

/*-------------------------------------------------------------------------
Name	: Pause
Purpose	: Used to stop anything that needs stopped when the state is
		  paused.
-------------------------------------------------------------------------*/
void StartState::Pause()
{

}

/*-------------------------------------------------------------------------
Name	: Resume
Purpose	: Used to resume anything that was stopped when the state was
		  paused.
-------------------------------------------------------------------------*/
void StartState::Resume()
{

}

/*-------------------------------------------------------------------------
Name	: Update
Purpose	: Checks for when the user starts the game.  
-------------------------------------------------------------------------*/
void StartState::Update(StateManager *state_manager)
{
	// if the enter key or the start button is pressed
	if (Services::Instance().GetInputManager().IsKeyPressed(sf::Keyboard::Return) || Services::Instance().GetInputManager().IsButtonPressed(0, InputManager::START))
	{
		// change to the game state
		state_manager->ChangeState(new GameState());
	}
}

/*-------------------------------------------------------------------------
Name	: Render
Purpose	: Renders the start screen.
-------------------------------------------------------------------------*/
void StartState::Render()
{
	window_->draw(start_);
}

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
