/*=========================================================================
Class Name	: StateManager
Authors		: Ewan Duncan
Description	: Stores all the states of the application and provides
functions to switch between them.
========================================================================*/

/*-------------------------------------------------------------------------
INCLUDES
-------------------------------------------------------------------------*/
#include "state_manager.h"

/*-------------------------------------------------------------------------
MEMBER FUNCTIONS
-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------
Name	: Clear
Purpose	: Clears a state from the vector.    
-------------------------------------------------------------------------*/
void StateManager::Clear()
{
	// get rid of the state at the back of the vector
	while (!states_vector.empty())
	{
		states_vector.back()->CleanUp();
		states_vector.pop_back();
	}
}

/*-------------------------------------------------------------------------
Name	: ChangeState
Purpose	: Switches to a specified state.  
-------------------------------------------------------------------------*/
void StateManager::ChangeState(State *state)
{
	// Cleanup and delete the current state
	if (!states_vector.empty())
	{
		states_vector.back()->CleanUp();
		states_vector.pop_back();
	}

	// store and initialise the new state
	states_vector.push_back(state);
	states_vector.back()->Init();
}

/*-------------------------------------------------------------------------
Name	: PushState
Purpose	: Pauses the current state and switches to a new one.  
-------------------------------------------------------------------------*/
void StateManager::PushState(State *state)
{
	// pause current state
	if (!states_vector.empty())
		states_vector.back()->Pause();

	// store and initialise the new state
	states_vector.push_back(state);
	states_vector.back()->Init();
}

/*-------------------------------------------------------------------------
Name	: PopState
Purpose	: Deletes the current state and resumes the previous one.
-------------------------------------------------------------------------*/
void StateManager::PopState()
{
	// clean up and leave current state
	if (!states_vector.empty())
	{
		states_vector.back()->CleanUp();
		states_vector.pop_back();
	}

	// resume the previous state
	if (!states_vector.empty())
		states_vector.back()->Resume();
}

/*-------------------------------------------------------------------------
END OF FILE
-------------------------------------------------------------------------*/
